package ch.epfl.ppo.gui;

import java.awt.BorderLayout;
import java.awt.image.BufferedImage;
import java.net.URL;

import javax.imageio.ImageIO;
import javax.swing.JFrame;

import ch.epfl.ppo.ColorRGB;
import ch.epfl.ppo.Image;
import ch.epfl.ppo.ImageCompositor;
import ch.epfl.ppo.LinearHorizontalGradientMask;
import ch.epfl.ppo.adapters.DiscreteImageAdapter;
import ch.epfl.ppo.generators.ChessboardGenerator;
import ch.epfl.ppo.transformers.RotationTransformer;

public final class ImageViewer {
    public static void main(String[] args) {
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            @Override
            public void run() {
                try {
                    // L'image à afficher, à modifier au fur et à mesure de
                    // votre avancement.
                    ColorRGB gray = new ColorRGB(0.5, 0.5, 0.5);
                    Image<ColorRGB> bg = new ChessboardGenerator(ColorRGB.WHITE, gray, 0.2);
                    URL imageURL = new URL("http://cs108.epfl.ch/images/dubrovnik.jpg");
                    BufferedImage discreteImage = ImageIO.read(imageURL);
                    Image<ColorRGB> fg = new DiscreteImageAdapter(ColorRGB.BLACK, discreteImage);
                    LinearHorizontalGradientMask mask = new LinearHorizontalGradientMask(-0.3, 0.3);
                    Image<Double> rotatedMask = new RotationTransformer<>(mask, Math.toRadians(45));
                    Image<ColorRGB> image = new ImageCompositor(bg, fg, rotatedMask);

                    JFrame mainWindow = new JFrame("Image viewer");
                    mainWindow.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

                    mainWindow.getContentPane().setLayout(new BorderLayout());
                    ImageComponent imageComponent = new ImageComponent(image, 0, 0, 4);
                    mainWindow.getContentPane().add(imageComponent, BorderLayout.CENTER);

                    mainWindow.pack();
                    mainWindow.setVisible(true);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }
}
